/* Generated by the protocol buffer compiler.  DO NOT EDIT! */
/* Generated from: envelope.proto */

/* Do not generate deprecated warnings for self */
#ifndef PROTOBUF_C__NO_DEPRECATED
#define PROTOBUF_C__NO_DEPRECATED
#endif

#include "envelope.pb-c.h"
void   carp__envelope__init
                     (Carp__Envelope         *message)
{
  static const Carp__Envelope init_value = CARP__ENVELOPE__INIT;
  *message = init_value;
}
size_t carp__envelope__get_packed_size
                     (const Carp__Envelope *message)
{
  assert(message->base.descriptor == &carp__envelope__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t carp__envelope__pack
                     (const Carp__Envelope *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &carp__envelope__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t carp__envelope__pack_to_buffer
                     (const Carp__Envelope *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &carp__envelope__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
Carp__Envelope *
       carp__envelope__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (Carp__Envelope *)
     protobuf_c_message_unpack (&carp__envelope__descriptor,
                                allocator, len, data);
}
void   carp__envelope__free_unpacked
                     (Carp__Envelope *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &carp__envelope__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
static const ProtobufCFieldDescriptor carp__envelope__field_descriptors[2] =
{
  {
    "content_type",
    1,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_STRING,
    0,   /* quantifier_offset */
    offsetof(Carp__Envelope, content_type),
    NULL,
    &protobuf_c_empty_string,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "content",
    2,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_BYTES,
    0,   /* quantifier_offset */
    offsetof(Carp__Envelope, content),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned carp__envelope__field_indices_by_name[] = {
  1,   /* field[1] = content */
  0,   /* field[0] = content_type */
};
static const ProtobufCIntRange carp__envelope__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 2 }
};
const ProtobufCMessageDescriptor carp__envelope__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "carp.Envelope",
  "Envelope",
  "Carp__Envelope",
  "carp",
  sizeof(Carp__Envelope),
  2,
  carp__envelope__field_descriptors,
  carp__envelope__field_indices_by_name,
  1,  carp__envelope__number_ranges,
  (ProtobufCMessageInit) carp__envelope__init,
  NULL,NULL,NULL    /* reserved[123] */
};
