# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pytypes.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rpytypes.proto\x12\x04\x63\x61rp\"\xe5\x01\n\x0bPythonValue\x12\x11\n\x07_string\x18\x01 \x01(\tH\x00\x12\x11\n\x07_double\x18\x02 \x01(\x01H\x00\x12\x0e\n\x04_int\x18\x03 \x01(\x12H\x00\x12\x10\n\x06_bytes\x18\x04 \x01(\x0cH\x00\x12\x15\n\x0b_serialized\x18\x05 \x01(\x0cH\x00\x12\x0f\n\x05_bool\x18\x06 \x01(\x08H\x00\x12\x0f\n\x05_none\x18\x07 \x01(\x08H\x00\x12#\n\x06_array\x18\x08 \x01(\x0b\x32\x11.carp.PythonArrayH\x00\x12!\n\x05_dict\x18\t \x01(\x0b\x32\x10.carp.PythonDictH\x00\x42\r\n\x0bvalue_types\"R\n\x0ePythonDictItem\x12\x1e\n\x03key\x18\x01 \x01(\x0b\x32\x11.carp.PythonValue\x12 \n\x05value\x18\x02 \x01(\x0b\x32\x11.carp.PythonValue\"1\n\nPythonDict\x12#\n\x05items\x18\x01 \x03(\x0b\x32\x14.carp.PythonDictItem\"/\n\x0bPythonArray\x12 \n\x05items\x18\x01 \x03(\x0b\x32\x11.carp.PythonValue\"8\n\x14PythonValueContainer\x12 \n\x05value\x18\x01 \x01(\x0b\x32\x11.carp.PythonValue\"8\n\x14PythonArrayContainer\x12 \n\x05value\x18\x01 \x01(\x0b\x32\x11.carp.PythonArray\"6\n\x13PythonDictContainer\x12\x1f\n\x05value\x18\x01 \x01(\x0b\x32\x10.carp.PythonDictb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'pytypes_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PYTHONVALUE._serialized_start=24
  _PYTHONVALUE._serialized_end=253
  _PYTHONDICTITEM._serialized_start=255
  _PYTHONDICTITEM._serialized_end=337
  _PYTHONDICT._serialized_start=339
  _PYTHONDICT._serialized_end=388
  _PYTHONARRAY._serialized_start=390
  _PYTHONARRAY._serialized_end=437
  _PYTHONVALUECONTAINER._serialized_start=439
  _PYTHONVALUECONTAINER._serialized_end=495
  _PYTHONARRAYCONTAINER._serialized_start=497
  _PYTHONARRAYCONTAINER._serialized_end=553
  _PYTHONDICTCONTAINER._serialized_start=555
  _PYTHONDICTCONTAINER._serialized_end=609
# @@protoc_insertion_point(module_scope)
