/* Generated by the protocol buffer compiler.  DO NOT EDIT! */
/* Generated from: pytypes.proto */

/* Do not generate deprecated warnings for self */
#ifndef PROTOBUF_C__NO_DEPRECATED
#define PROTOBUF_C__NO_DEPRECATED
#endif

#include "pytypes.pb-c.h"
void   carp__python_value__init
                     (Carp__PythonValue         *message)
{
  static const Carp__PythonValue init_value = CARP__PYTHON_VALUE__INIT;
  *message = init_value;
}
size_t carp__python_value__get_packed_size
                     (const Carp__PythonValue *message)
{
  assert(message->base.descriptor == &carp__python_value__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t carp__python_value__pack
                     (const Carp__PythonValue *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &carp__python_value__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t carp__python_value__pack_to_buffer
                     (const Carp__PythonValue *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &carp__python_value__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
Carp__PythonValue *
       carp__python_value__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (Carp__PythonValue *)
     protobuf_c_message_unpack (&carp__python_value__descriptor,
                                allocator, len, data);
}
void   carp__python_value__free_unpacked
                     (Carp__PythonValue *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &carp__python_value__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
void   carp__python_dict_item__init
                     (Carp__PythonDictItem         *message)
{
  static const Carp__PythonDictItem init_value = CARP__PYTHON_DICT_ITEM__INIT;
  *message = init_value;
}
size_t carp__python_dict_item__get_packed_size
                     (const Carp__PythonDictItem *message)
{
  assert(message->base.descriptor == &carp__python_dict_item__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t carp__python_dict_item__pack
                     (const Carp__PythonDictItem *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &carp__python_dict_item__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t carp__python_dict_item__pack_to_buffer
                     (const Carp__PythonDictItem *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &carp__python_dict_item__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
Carp__PythonDictItem *
       carp__python_dict_item__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (Carp__PythonDictItem *)
     protobuf_c_message_unpack (&carp__python_dict_item__descriptor,
                                allocator, len, data);
}
void   carp__python_dict_item__free_unpacked
                     (Carp__PythonDictItem *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &carp__python_dict_item__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
void   carp__python_dict__init
                     (Carp__PythonDict         *message)
{
  static const Carp__PythonDict init_value = CARP__PYTHON_DICT__INIT;
  *message = init_value;
}
size_t carp__python_dict__get_packed_size
                     (const Carp__PythonDict *message)
{
  assert(message->base.descriptor == &carp__python_dict__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t carp__python_dict__pack
                     (const Carp__PythonDict *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &carp__python_dict__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t carp__python_dict__pack_to_buffer
                     (const Carp__PythonDict *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &carp__python_dict__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
Carp__PythonDict *
       carp__python_dict__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (Carp__PythonDict *)
     protobuf_c_message_unpack (&carp__python_dict__descriptor,
                                allocator, len, data);
}
void   carp__python_dict__free_unpacked
                     (Carp__PythonDict *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &carp__python_dict__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
void   carp__python_array__init
                     (Carp__PythonArray         *message)
{
  static const Carp__PythonArray init_value = CARP__PYTHON_ARRAY__INIT;
  *message = init_value;
}
size_t carp__python_array__get_packed_size
                     (const Carp__PythonArray *message)
{
  assert(message->base.descriptor == &carp__python_array__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t carp__python_array__pack
                     (const Carp__PythonArray *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &carp__python_array__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t carp__python_array__pack_to_buffer
                     (const Carp__PythonArray *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &carp__python_array__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
Carp__PythonArray *
       carp__python_array__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (Carp__PythonArray *)
     protobuf_c_message_unpack (&carp__python_array__descriptor,
                                allocator, len, data);
}
void   carp__python_array__free_unpacked
                     (Carp__PythonArray *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &carp__python_array__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
void   carp__python_value_container__init
                     (Carp__PythonValueContainer         *message)
{
  static const Carp__PythonValueContainer init_value = CARP__PYTHON_VALUE_CONTAINER__INIT;
  *message = init_value;
}
size_t carp__python_value_container__get_packed_size
                     (const Carp__PythonValueContainer *message)
{
  assert(message->base.descriptor == &carp__python_value_container__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t carp__python_value_container__pack
                     (const Carp__PythonValueContainer *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &carp__python_value_container__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t carp__python_value_container__pack_to_buffer
                     (const Carp__PythonValueContainer *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &carp__python_value_container__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
Carp__PythonValueContainer *
       carp__python_value_container__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (Carp__PythonValueContainer *)
     protobuf_c_message_unpack (&carp__python_value_container__descriptor,
                                allocator, len, data);
}
void   carp__python_value_container__free_unpacked
                     (Carp__PythonValueContainer *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &carp__python_value_container__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
void   carp__python_array_container__init
                     (Carp__PythonArrayContainer         *message)
{
  static const Carp__PythonArrayContainer init_value = CARP__PYTHON_ARRAY_CONTAINER__INIT;
  *message = init_value;
}
size_t carp__python_array_container__get_packed_size
                     (const Carp__PythonArrayContainer *message)
{
  assert(message->base.descriptor == &carp__python_array_container__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t carp__python_array_container__pack
                     (const Carp__PythonArrayContainer *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &carp__python_array_container__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t carp__python_array_container__pack_to_buffer
                     (const Carp__PythonArrayContainer *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &carp__python_array_container__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
Carp__PythonArrayContainer *
       carp__python_array_container__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (Carp__PythonArrayContainer *)
     protobuf_c_message_unpack (&carp__python_array_container__descriptor,
                                allocator, len, data);
}
void   carp__python_array_container__free_unpacked
                     (Carp__PythonArrayContainer *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &carp__python_array_container__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
void   carp__python_dict_container__init
                     (Carp__PythonDictContainer         *message)
{
  static const Carp__PythonDictContainer init_value = CARP__PYTHON_DICT_CONTAINER__INIT;
  *message = init_value;
}
size_t carp__python_dict_container__get_packed_size
                     (const Carp__PythonDictContainer *message)
{
  assert(message->base.descriptor == &carp__python_dict_container__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t carp__python_dict_container__pack
                     (const Carp__PythonDictContainer *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &carp__python_dict_container__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t carp__python_dict_container__pack_to_buffer
                     (const Carp__PythonDictContainer *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &carp__python_dict_container__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
Carp__PythonDictContainer *
       carp__python_dict_container__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (Carp__PythonDictContainer *)
     protobuf_c_message_unpack (&carp__python_dict_container__descriptor,
                                allocator, len, data);
}
void   carp__python_dict_container__free_unpacked
                     (Carp__PythonDictContainer *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &carp__python_dict_container__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
static const ProtobufCFieldDescriptor carp__python_value__field_descriptors[9] =
{
  {
    "_string",
    1,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_STRING,
    offsetof(Carp__PythonValue, value_types_case),
    offsetof(Carp__PythonValue, _string),
    NULL,
    &protobuf_c_empty_string,
    0 | PROTOBUF_C_FIELD_FLAG_ONEOF,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "_double",
    2,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_DOUBLE,
    offsetof(Carp__PythonValue, value_types_case),
    offsetof(Carp__PythonValue, _double),
    NULL,
    NULL,
    0 | PROTOBUF_C_FIELD_FLAG_ONEOF,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "_int",
    3,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_SINT64,
    offsetof(Carp__PythonValue, value_types_case),
    offsetof(Carp__PythonValue, _int),
    NULL,
    NULL,
    0 | PROTOBUF_C_FIELD_FLAG_ONEOF,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "_bytes",
    4,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_BYTES,
    offsetof(Carp__PythonValue, value_types_case),
    offsetof(Carp__PythonValue, _bytes),
    NULL,
    NULL,
    0 | PROTOBUF_C_FIELD_FLAG_ONEOF,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "_serialized",
    5,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_BYTES,
    offsetof(Carp__PythonValue, value_types_case),
    offsetof(Carp__PythonValue, _serialized),
    NULL,
    NULL,
    0 | PROTOBUF_C_FIELD_FLAG_ONEOF,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "_bool",
    6,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_BOOL,
    offsetof(Carp__PythonValue, value_types_case),
    offsetof(Carp__PythonValue, _bool),
    NULL,
    NULL,
    0 | PROTOBUF_C_FIELD_FLAG_ONEOF,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "_none",
    7,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_BOOL,
    offsetof(Carp__PythonValue, value_types_case),
    offsetof(Carp__PythonValue, _none),
    NULL,
    NULL,
    0 | PROTOBUF_C_FIELD_FLAG_ONEOF,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "_array",
    8,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_MESSAGE,
    offsetof(Carp__PythonValue, value_types_case),
    offsetof(Carp__PythonValue, _array),
    &carp__python_array__descriptor,
    NULL,
    0 | PROTOBUF_C_FIELD_FLAG_ONEOF,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "_dict",
    9,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_MESSAGE,
    offsetof(Carp__PythonValue, value_types_case),
    offsetof(Carp__PythonValue, _dict),
    &carp__python_dict__descriptor,
    NULL,
    0 | PROTOBUF_C_FIELD_FLAG_ONEOF,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned carp__python_value__field_indices_by_name[] = {
  7,   /* field[7] = _array */
  5,   /* field[5] = _bool */
  3,   /* field[3] = _bytes */
  8,   /* field[8] = _dict */
  1,   /* field[1] = _double */
  2,   /* field[2] = _int */
  6,   /* field[6] = _none */
  4,   /* field[4] = _serialized */
  0,   /* field[0] = _string */
};
static const ProtobufCIntRange carp__python_value__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 9 }
};
const ProtobufCMessageDescriptor carp__python_value__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "carp.PythonValue",
  "PythonValue",
  "Carp__PythonValue",
  "carp",
  sizeof(Carp__PythonValue),
  9,
  carp__python_value__field_descriptors,
  carp__python_value__field_indices_by_name,
  1,  carp__python_value__number_ranges,
  (ProtobufCMessageInit) carp__python_value__init,
  NULL,NULL,NULL    /* reserved[123] */
};
static const ProtobufCFieldDescriptor carp__python_dict_item__field_descriptors[2] =
{
  {
    "key",
    1,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_MESSAGE,
    0,   /* quantifier_offset */
    offsetof(Carp__PythonDictItem, key),
    &carp__python_value__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "value",
    2,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_MESSAGE,
    0,   /* quantifier_offset */
    offsetof(Carp__PythonDictItem, value),
    &carp__python_value__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned carp__python_dict_item__field_indices_by_name[] = {
  0,   /* field[0] = key */
  1,   /* field[1] = value */
};
static const ProtobufCIntRange carp__python_dict_item__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 2 }
};
const ProtobufCMessageDescriptor carp__python_dict_item__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "carp.PythonDictItem",
  "PythonDictItem",
  "Carp__PythonDictItem",
  "carp",
  sizeof(Carp__PythonDictItem),
  2,
  carp__python_dict_item__field_descriptors,
  carp__python_dict_item__field_indices_by_name,
  1,  carp__python_dict_item__number_ranges,
  (ProtobufCMessageInit) carp__python_dict_item__init,
  NULL,NULL,NULL    /* reserved[123] */
};
static const ProtobufCFieldDescriptor carp__python_dict__field_descriptors[1] =
{
  {
    "items",
    1,
    PROTOBUF_C_LABEL_REPEATED,
    PROTOBUF_C_TYPE_MESSAGE,
    offsetof(Carp__PythonDict, n_items),
    offsetof(Carp__PythonDict, items),
    &carp__python_dict_item__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned carp__python_dict__field_indices_by_name[] = {
  0,   /* field[0] = items */
};
static const ProtobufCIntRange carp__python_dict__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 1 }
};
const ProtobufCMessageDescriptor carp__python_dict__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "carp.PythonDict",
  "PythonDict",
  "Carp__PythonDict",
  "carp",
  sizeof(Carp__PythonDict),
  1,
  carp__python_dict__field_descriptors,
  carp__python_dict__field_indices_by_name,
  1,  carp__python_dict__number_ranges,
  (ProtobufCMessageInit) carp__python_dict__init,
  NULL,NULL,NULL    /* reserved[123] */
};
static const ProtobufCFieldDescriptor carp__python_array__field_descriptors[1] =
{
  {
    "items",
    1,
    PROTOBUF_C_LABEL_REPEATED,
    PROTOBUF_C_TYPE_MESSAGE,
    offsetof(Carp__PythonArray, n_items),
    offsetof(Carp__PythonArray, items),
    &carp__python_value__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned carp__python_array__field_indices_by_name[] = {
  0,   /* field[0] = items */
};
static const ProtobufCIntRange carp__python_array__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 1 }
};
const ProtobufCMessageDescriptor carp__python_array__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "carp.PythonArray",
  "PythonArray",
  "Carp__PythonArray",
  "carp",
  sizeof(Carp__PythonArray),
  1,
  carp__python_array__field_descriptors,
  carp__python_array__field_indices_by_name,
  1,  carp__python_array__number_ranges,
  (ProtobufCMessageInit) carp__python_array__init,
  NULL,NULL,NULL    /* reserved[123] */
};
static const ProtobufCFieldDescriptor carp__python_value_container__field_descriptors[1] =
{
  {
    "value",
    1,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_MESSAGE,
    0,   /* quantifier_offset */
    offsetof(Carp__PythonValueContainer, value),
    &carp__python_value__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned carp__python_value_container__field_indices_by_name[] = {
  0,   /* field[0] = value */
};
static const ProtobufCIntRange carp__python_value_container__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 1 }
};
const ProtobufCMessageDescriptor carp__python_value_container__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "carp.PythonValueContainer",
  "PythonValueContainer",
  "Carp__PythonValueContainer",
  "carp",
  sizeof(Carp__PythonValueContainer),
  1,
  carp__python_value_container__field_descriptors,
  carp__python_value_container__field_indices_by_name,
  1,  carp__python_value_container__number_ranges,
  (ProtobufCMessageInit) carp__python_value_container__init,
  NULL,NULL,NULL    /* reserved[123] */
};
static const ProtobufCFieldDescriptor carp__python_array_container__field_descriptors[1] =
{
  {
    "value",
    1,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_MESSAGE,
    0,   /* quantifier_offset */
    offsetof(Carp__PythonArrayContainer, value),
    &carp__python_array__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned carp__python_array_container__field_indices_by_name[] = {
  0,   /* field[0] = value */
};
static const ProtobufCIntRange carp__python_array_container__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 1 }
};
const ProtobufCMessageDescriptor carp__python_array_container__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "carp.PythonArrayContainer",
  "PythonArrayContainer",
  "Carp__PythonArrayContainer",
  "carp",
  sizeof(Carp__PythonArrayContainer),
  1,
  carp__python_array_container__field_descriptors,
  carp__python_array_container__field_indices_by_name,
  1,  carp__python_array_container__number_ranges,
  (ProtobufCMessageInit) carp__python_array_container__init,
  NULL,NULL,NULL    /* reserved[123] */
};
static const ProtobufCFieldDescriptor carp__python_dict_container__field_descriptors[1] =
{
  {
    "value",
    1,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_MESSAGE,
    0,   /* quantifier_offset */
    offsetof(Carp__PythonDictContainer, value),
    &carp__python_dict__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned carp__python_dict_container__field_indices_by_name[] = {
  0,   /* field[0] = value */
};
static const ProtobufCIntRange carp__python_dict_container__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 1 }
};
const ProtobufCMessageDescriptor carp__python_dict_container__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "carp.PythonDictContainer",
  "PythonDictContainer",
  "Carp__PythonDictContainer",
  "carp",
  sizeof(Carp__PythonDictContainer),
  1,
  carp__python_dict_container__field_descriptors,
  carp__python_dict_container__field_indices_by_name,
  1,  carp__python_dict_container__number_ranges,
  (ProtobufCMessageInit) carp__python_dict_container__init,
  NULL,NULL,NULL    /* reserved[123] */
};
